@@ -14,6 +14,9 @@ CASTERS = [
     lambda a: UUID(a),
 ]
 
+STOP_CHARACTERS = [":", ",", "]", "}", ")"]
+STRING_CHARACTERS = ["'", '"']
+
 
 class InvalidKwarg(Exception):
     pass
@@ -55,9 +58,9 @@ def parse_kwarg(kwarg: str, raise_if_unparseable=False) -> Dict[str, Any]:
                 f"{kwarg} key cannot contain a single quote or double quote"
             )
 
-    # Attempt to parse the value into a primitive, but return it un-parsed if not possible
-    # because the value can be a template variable that will get set from the context when
-    # the templatetag is rendered
+    # Attempt to parse the value into a primitive, but allow it to be returned if not possible
+    # (the value can be a template variable that will get set from the context when
+    # the templatetag is rendered in which case it can't be parsed in this manner)
     try:
         val = parse_args(val)[0]
     except ValueError:
@@ -81,10 +84,13 @@ def parse_args(args: str) -> List[Any]:
     """
     found_args = []
     arg = ""
+
     curly_bracket_count = 0
     square_bracket_count = 0
     parenthesis_count = 0
 
+    inside_string = False
+
     def _eval_arg(_arg):
         try:
             _arg = literal_eval(_arg)
@@ -114,11 +120,19 @@ def parse_args(args: str) -> List[Any]:
         return _arg
 
     for c in args:
-        if not c.strip():
+        if len(arg) > 1:
+            if c in STOP_CHARACTERS:
+                previous_char = arg[-1:][0]
+
+                if previous_char == "'":
+                    inside_string = False
+
+        if not inside_string and not c.strip():
             continue
 
         if (
             c == ","
+            and not inside_string
             and curly_bracket_count == 0
             and square_bracket_count == 0
             and parenthesis_count == 0
@@ -147,8 +161,13 @@ def parse_args(args: str) -> List[Any]:
         elif c == ")":
             parenthesis_count -= 1
             arg = _parse_arg(arg)
+        elif c in STRING_CHARACTERS:
+            inside_string = True
 
     if arg:
+        if arg.startswith("'") and arg.endswith("'") and len(arg.split("'")) > 3:
+            arg = arg[1:-1]
+
         arg = _eval_arg(arg)
         found_args.append(arg)
 
