@@ -1,4 +1,5 @@
-import { Component } from "./component.js"
+import { Component } from "./component.js";
+import { isEmpty } from "./utils.js";
 
 let messageUrl = "";
 const csrfTokenHeaderName = "X-CSRFToken";
@@ -23,6 +24,7 @@ export function componentInit(args) {
   components[component.id] = component;
 
   component.setModelValues();
+  component.setDbModelValues();
 }
 
 /**
@@ -32,7 +34,7 @@ export function call(componentName, methodName) {
   let component;
 
   Object.keys(components).forEach((id) => {
-    if (typeof component === "undefined") {
+    if (isEmpty(component)) {
       const _component = components[id];
 
       if (_component.name === componentName) {
